@@ -45,6 +45,7 @@ class FeedEntry(object):
 		self.__rss_category    = None
 		self.__rss_comments    = None
 		self.__rss_description = None
+		self.__rss_content     = None
 		self.__rss_enclosure   = None
 		self.__rss_guid        = None
 		self.__rss_link        = None
@@ -56,13 +57,9 @@ class FeedEntry(object):
 		self.__extensions = {}
 
 
-	def atom_entry(self, feed, extensions=True):
-		'''Insert an ATOM entry into a existing XML structure. Normally you
-		would pass the feed node of an ATOM feed XML to this function.
-
-		:param feed: The XML element to use as parent node for the element.
-		'''
-		entry = etree.SubElement(feed, 'entry')
+	def atom_entry(self, extensions=True):
+		'''Create an ATOM entry and return it.'''
+		entry = etree.Element('entry')
 		if not ( self.__atom_id and self.__atom_title and self.__atom_updated ):
 			raise ValueError('Required fields not set')
 		id      = etree.SubElement(entry, 'id')
@@ -105,6 +102,8 @@ class FeedEntry(object):
 					content.append(etree.fromstring('''<div
 							xmlns="http://www.w3.org/1999/xhtml">%s</div>''' % \
 							self.__atom_content.get('content')))
+				elif type == 'CDATA':
+					content.text = etree.CDATA(self.__atom_content)
 				# Emed the text in escaped form
 				elif not type or type.startswith('text') or type == 'html':
 					content.text = self.__atom_content.get('content')
@@ -169,19 +168,15 @@ class FeedEntry(object):
 		if extensions:
 			for ext in self.__extensions.values() or []:
 				if ext.get('atom'):
-					entry = ext['inst'].extend_atom(entry)
+					ext['inst'].extend_atom(entry)
 
 		return entry
 
 
-	def rss_entry(self, feed, extensions=True):
-		'''Insert an RSS item into a existing XML structure. Normally you
-		would pass the channel node of an RSS feed XML to this function.
-
-		:param feed: The XML element to use as parent node for the item.
-		'''
-		entry = etree.SubElement(feed, 'item')
-		if not ( self.__rss_title or self.__rss_description ):
+	def rss_entry(self, extensions=True):
+		'''Create a RSS item and return it.'''
+		entry = etree.Element('item')
+		if not ( self.__rss_title or self.__rss_description or self.__rss_content):
 			raise ValueError('Required fields not set')
 		if self.__rss_title:
 			title = etree.SubElement(entry, 'title')
@@ -189,9 +184,19 @@ class FeedEntry(object):
 		if self.__rss_link:
 			link = etree.SubElement(entry, 'link')
 			link.text = self.__rss_link
-		if self.__rss_description:
+		if self.__rss_description and self.__rss_content:
 			description = etree.SubElement(entry, 'description')
 			description.text = self.__rss_description
+			content = etree.SubElement(entry, '{%s}encoded' %
+									'http://purl.org/rss/1.0/modules/content/')
+			content.text = etree.CDATA(self.__rss_content['content']) \
+				if self.__rss_content.get('type', '') == 'CDATA' else self.__rss_content['content']
+		elif self.__rss_description:
+			description = etree.SubElement(entry, 'description')
+			description.text = self.__rss_description
+		elif self.__rss_content:
+			description = etree.SubElement(entry, 'description')
+			description.text = self.__rss_content['content']
 		for a in self.__rss_author or []:
 			author = etree.SubElement(entry, 'author')
 			author.text = a
@@ -220,12 +225,12 @@ class FeedEntry(object):
 		if extensions:
 			for ext in self.__extensions.values() or []:
 				if ext.get('rss'):
-					entry = ext['inst'].extend_rss(entry)
+					ext['inst'].extend_rss(entry)
 
 		return entry
 
 
-	
+
 	def title(self, title=None):
 		'''Get or set the title value of the entry. It should contain a human
 		readable title for the entry. Title is mandatory for both ATOM and RSS
@@ -303,7 +308,7 @@ class FeedEntry(object):
 		- *name* conveys a human-readable name for the person.
 		- *uri* contains a home page for the person.
 		- *email* contains an email address for the person.
-		
+
 		:param author:  Dict or list of dicts with author data.
 		:param replace: Add or replace old data.
 
@@ -325,7 +330,7 @@ class FeedEntry(object):
 		if not author is None:
 			if replace or self.__atom_author is None:
 				self.__atom_author = []
-			self.__atom_author += ensure_format( author, 
+			self.__atom_author += ensure_format( author,
 					set(['name', 'email', 'uri']), set(['name']))
 			self.__rss_author = []
 			for a in self.__atom_author:
@@ -343,15 +348,17 @@ class FeedEntry(object):
 
 		:param content: The content of the feed entry.
 		:param src: Link to the entries content.
+		:param type: If type is CDATA content would not be escaped.
 		:returns: Content element of the entry.
 		'''
 		if not src is None:
 			self.__atom_content = {'src':src}
 		elif not content is None:
 			self.__atom_content = {'content':content}
+			self.__rss_content = {'content':content}
 			if not type is None:
 				self.__atom_content['type'] = type
-			self.__rss_description = content
+				self.__rss_content['type'] = type
 		return self.__atom_content
 
 
@@ -392,7 +399,7 @@ class FeedEntry(object):
 		RSS also supports one enclusure element per entry which is covered by the
 		link element in ATOM feed entries. So for the RSS enclusure element the
 		last link with rel=enclosure is used.
-		
+
 		:param link:    Dict or list of dicts with data.
 		:param replace: Add or replace old data.
 		:returns: List of link data.
@@ -402,9 +409,9 @@ class FeedEntry(object):
 		if not link is None:
 			if replace or self.__atom_link is None:
 				self.__atom_link = []
-			self.__atom_link += ensure_format( link, 
+			self.__atom_link += ensure_format( link,
 					set(['href', 'rel', 'type', 'hreflang', 'title', 'length']),
-					set(['href']), 
+					set(['href']),
 					{'rel':['alternate', 'enclosure', 'related', 'self', 'via']},
 					{'rel': 'alternate'} )
 			# RSS only needs one URL. We use the first link for RSS:
@@ -476,7 +483,7 @@ class FeedEntry(object):
 		If a label is present it is used for the RSS feeds. Otherwise the term is
 		used. The scheme is used for the domain attribute in RSS.
 
-		:param link:    Dict or list of dicts with data.
+		:param category:    Dict or list of dicts with data.
 		:param replace: Add or replace old data.
 		:returns: List of category data.
 		'''
@@ -485,8 +492,8 @@ class FeedEntry(object):
 		if not category is None:
 			if replace or self.__atom_category is None:
 				self.__atom_category = []
-			self.__atom_category += ensure_format( 
-					category, 
+			self.__atom_category += ensure_format(
+					category,
 					set(['term', 'scheme', 'label']),
 					set(['term']) )
 			# Map the ATOM categories to RSS categories. Use the atom:label as
@@ -515,7 +522,7 @@ class FeedEntry(object):
 		- *name* conveys a human-readable name for the person.
 		- *uri* contains a home page for the person.
 		- *email* contains an email address for the person.
-		
+
 		:param contributor: Dictionary or list of dictionaries with contributor data.
 		:param replace: Add or replace old data.
 		:returns: List of contributors as dictionaries.
@@ -525,7 +532,7 @@ class FeedEntry(object):
 		if not contributor is None:
 			if replace or self.__atom_contributor is None:
 				self.__atom_contributor = []
-			self.__atom_contributor += ensure_format( contributor, 
+			self.__atom_contributor += ensure_format( contributor,
 					set(['name', 'email', 'uri']), set(['name']))
 		return self.__atom_contributor
 
@@ -553,7 +560,7 @@ class FeedEntry(object):
 
 		return self.__atom_published
 
-	
+
 	def pubdate(self, pubDate=None):
 		'''Get or set the pubDate of the entry which indicates when the entry was
 		published. This method is just another name for the published(...)
@@ -617,7 +624,7 @@ class FeedEntry(object):
 			self.__rss_ttl = int(ttl)
 		return self.__rss_ttl
 
-	
+
 	def load_extension(self, name, atom=True, rss=True):
 		'''Load a specific extension by name.
 
